==> MafDb.ESP6500SI.V2.SSA137.hs37d5_3.6.0.tar.gz: MafDb.ESP6500SI.V2.SSA137.hs37d5/R/zzz.R <==
.onLoad <- function(libname, pkgname) {
  extdata_dirpath <- system.file("extdata", package=pkgname,
                                 lib.loc=libname, mustWork=TRUE)

  ## fetch the metadata from the smallest file to minimize loading time
  finfo <- file.info(list.files(pattern=sprintf("%s.[A-Z]+_AF.", pkgname), path=extdata_dirpath,
                                full.names=TRUE))

  obj <- readRDS(file.path(extdata_dirpath, basename(rownames(finfo)[which.min(finfo$size)])))
  mdobj <- metadata(obj)
  stopifnot(identical(pkgname, mdobj$data_pkgname)) ## QC
  popname <- basename(rownames(finfo)[which.min(finfo$size)])
  popname <- gsub("\\..+$", "", gsub(sprintf("%s.", pkgname), "", popname))

  serializedobjs <- rownames(finfo)
  names(serializedobjs) <- serializedobjs

  ## Make and export MafDb object.
  mafobj <- MafDb(provider=mdobj$provider,
                  provider_version=mdobj$provider_version,
                  download_url=mdobj$download_url,
                  download_date=mdobj$download_date,
                  reference_genome=mdobj$reference_genome,
                  data_pkgname=pkgname,
                  data_dirpath=extdata_dirpath,
                  data_serialized_objnames=serializedobjs,
                  data_tag="ESP")

  mafsnvs <- get(sprintf("%s", pkgname), envir=mafobj@.data_cache)
  mafsnvs[[popname]] <- list()
  mafsnvs[[popname]][[mdobj$seqname]] <- obj
  assign(sprintf("%s", pkgname), mafsnvs, envir=mafobj@.data_cache)

  ns <- asNamespace(pkgname)
  assign(pkgname, mafobj, envir=ns)

  namespaceExport(ns, pkgname)
}

==> MafDb.ESP6500SI.V2.SSA137.hs37d5_3.7.0.tar.gz: MafDb.ESP6500SI.V2.SSA137.hs37d5/R/zzz.R <==
.onLoad <- function(libname, pkgname) {
  extdata_dirpath <- system.file("extdata", package=pkgname,
                                 lib.loc=libname, mustWork=TRUE)

  ## fetch the metadata from the smallest file to minimize loading time
  finfo <- file.info(list.files(pattern=sprintf("%s\\.AF\\.", pkgname), path=extdata_dirpath,
                                full.names=TRUE))
  obj <- readRDS(file.path(extdata_dirpath, basename(rownames(finfo)[which.min(finfo$size)])))
  mdobj <- metadata(obj)
  stopifnot(identical(pkgname, mdobj$data_pkgname)) ## QC
  popname <- basename(rownames(finfo)[which.min(finfo$size)])
  popname <- gsub("\\..+$", "", gsub(sprintf("%s.", pkgname), "", popname))
  if (popname %in% seqlevels(mdobj$reference_genome))
    popname <- "default"

  serializedobjs <- rownames(finfo)
  names(serializedobjs) <- serializedobjs

  ## Make and export the GScores object.
  gsco <- GScores(provider=mdobj$provider,
                  provider_version=mdobj$provider_version,
                  download_url=mdobj$download_url,
                  download_date=mdobj$download_date,
                  reference_genome=mdobj$reference_genome,
                  data_pkgname=pkgname,
                  data_dirpath=extdata_dirpath,
                  data_serialized_objnames=serializedobjs,
                  default_pop="AF",
                  data_group="MAF",
                  data_tag="ESP")
  gscopops <- get(pkgname, envir=gsco@.data_cache)
  gscopops[[popname]] <- RleList(compress=FALSE)
  gscopops[[popname]][[mdobj$seqname]] <- obj
  assign(pkgname, gscopops, envir=gsco@.data_cache)

  ns <- asNamespace(pkgname)
  assign(pkgname, gsco, envir=ns)

  namespaceExport(ns, pkgname)
}
